@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2021 by The BRLTTY Developers.
+ * Copyright (C) 1995-2023 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -334,6 +334,8 @@ extern "C" {
 #define BRL_CMD_CONTRACTED (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CONTRACTED)
 /** set six/eight dot computer braille */
 #define BRL_CMD_COMPBRL6 (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_COMPBRL6)
+/** reset preferences to defaults */
+#define BRL_CMD_PREFRESET (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_PREFRESET)
 /** bring screen cursor to character */
 #define BRL_BLK_ROUTE (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE)
 /** start new clipboard at character */
@@ -400,6 +402,8 @@ extern "C" {
 #define BRL_BLK_TXTSEL_START (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TXTSEL_START)
 /** set text selection */
 #define BRL_BLK_TXTSEL_SET (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TXTSEL_SET)
+/** bring speech cursor to character */
+#define BRL_BLK_ROUTE_SPEECH (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_ROUTE_SPEECH)
 /** bind to specific virtual terminal */
 #define BRL_BLK_SELECTVT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_SELECTVT)
 /** render an alert */
@@ -418,6 +422,10 @@ extern "C" {
 #define BRL_BLK_CONTEXT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_CONTEXT)
 /** current reading location */
 #define BRL_BLK_TOUCH_AT (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_TOUCH_AT)
+/** execute command macro */
+#define BRL_BLK_MACRO (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_MACRO)
+/** run host command */
+#define BRL_BLK_HOSTCMD (BRLAPI_KEY_TYPE_CMD | BRLAPI_KEY_CMD_HOSTCMD)
 /** enter key */
 #define BRL_KEY_ENTER (BRLAPI_KEY_SYM_LINEFEED & 0XFF)
 /** tab key */
@@ -472,6 +480,8 @@ extern "C" {
 #define BRL_FLG_INPUT_ALTGR BRLAPI_KEY_FLG_INPUT_ALTGR
 /** gui (windows) key pressed */
 #define BRL_FLG_INPUT_GUI BRLAPI_KEY_FLG_INPUT_GUI
+/** prefix with escape */
+#define BRL_FLG_INPUT_ESCAPED BRLAPI_KEY_FLG_INPUT_ESCAPED
 /** it is a release scan code */
 #define BRL_FLG_KBD_RELEASE BRLAPI_KEY_FLG_KBD_RELEASE
 /** it is an emulation 0 scan code */
