@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2018 by The BRLTTY Developers.
+ * Copyright (C) 1995-2023 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -19,6 +19,8 @@
 #ifndef BRLTTY_INCLUDED_PCM
 #define BRLTTY_INCLUDED_PCM
 
+#include "prologue.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -27,9 +29,6 @@ typedef enum {
   PCM_FMT_S8,   // signed, 8 bits, linear
   PCM_FMT_U8,   // unsigned, 8 bits, linear
 
-  PCM_FMT_S16N, // signed, 16 bits, linear, native endian
-  PCM_FMT_U16N, // unsigned, 16 bits, linear, native endian
-
   PCM_FMT_S16B, // signed, 16 bits, linear, big endian
   PCM_FMT_U16B, // unsigned, 16 bits, linear, big endian
 
@@ -42,6 +41,14 @@ typedef enum {
   PCM_FMT_UNKNOWN
 } PcmAmplitudeFormat;
 
+#ifdef WORDS_BIGENDIAN
+#define PCM_FMT_S16N PCM_FMT_S16B
+#define PCM_FMT_U16N PCM_FMT_U16B
+#else /* WORDS_BIGENDIAN */
+#define PCM_FMT_S16N PCM_FMT_S16L
+#define PCM_FMT_U16N PCM_FMT_U16L
+#endif /* WORDS_BIGENDIAN */
+
 #define PCM_MAX_SAMPLE_SIZE 2
 
 typedef union {
@@ -69,7 +76,7 @@ extern PcmAmplitudeFormat getPcmAmplitudeFormat (PcmDevice *pcm);
 extern PcmAmplitudeFormat setPcmAmplitudeFormat (PcmDevice *pcm, PcmAmplitudeFormat format);
 
 extern int writePcmData (PcmDevice *pcm, const unsigned char *buffer, int count);
-extern void forcePcmOutput (PcmDevice *pcm);
+extern void pushPcmOutput (PcmDevice *pcm);
 extern void awaitPcmOutput (PcmDevice *pcm);
 extern void cancelPcmOutput (PcmDevice *pcm);
 
